@@ -22,7 +22,7 @@
 #define __W_ISERIES_H__
 
 #include <glib.h>
-#include <wtap.h>
+#include "wtap.h"
 
 wtap_open_return_val iseries_open(wtap *wth, int *err, gchar **err_info);
 
